Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3379)

Unified Diff: chrome/browser/instant/instant_controller.h

Issue 12047107: Change the SearchBox API from using the start/end margins of the location bar to using the start ma… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Added test Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_controller.h
diff --git a/chrome/browser/instant/instant_controller.h b/chrome/browser/instant/instant_controller.h
index 05ec11bd32c179cd50ee0c50b1e75450116426e8..0b3157f0838c8ada68928608f43f7f7438b6d894 100644
--- a/chrome/browser/instant/instant_controller.h
+++ b/chrome/browser/instant/instant_controller.h
@@ -81,8 +81,8 @@ class InstantController {
// Sets the bounds of the omnibox popup, in screen coordinates.
void SetPopupBounds(const gfx::Rect& bounds);
- // Sets the start and end margins of the omnibox text area.
- void SetMarginSize(int start, int end);
+ // Sets the stored start-edge margin and width.
+ void SetStartMarginAndWidth(int margin, int width);
// Send autocomplete results from |providers| to the preview page.
void HandleAutocompleteResults(
@@ -322,11 +322,10 @@ class InstantController {
// Last popup bounds passed to the page.
gfx::Rect last_popup_bounds_;
// Size of the start-edge omnibox text area margin.
int start_margin_;
-
- // Size of the end-edge omnibox text area margin.
- int end_margin_;
+ int width_;
// Timer used to update the bounds of the omnibox popup.
base::OneShotTimer<InstantController> update_bounds_timer_;
@@ -322,11 +322,10 @@ class InstantController {
// Last popup bounds passed to the page.
gfx::Rect last_popup_bounds_;
- // Size of the start-edge omnibox text area margin.
+ // The start-edge margin and width to use for aligning the preview contents
+ // with the omnibox.
int start_margin_;

Powered by Google App Engine
This is Rietveld 408576698